# Security Policy

## Reporting a Vulnerability

If you've found a security vulnerability in ``pdbp``, (or a dependency we use), please open an issue.

[github.com/mdmintz/pdbp/issues](https://github.com/mdmintz/pdbp/issues)

Please describe the results you're seeing, and the results you're expecting.
